@@ -12,6 +12,7 @@ from artify import deploy
 from artify import syncrepo
 from artify import change_version
 from artify import generate_file
+from artify import extract_commands
 
 debug = 0;
 
@@ -339,7 +340,8 @@ def main(argv):
         #document artifact changes
         pass
     elif action == 'extract':
-        pass    
+        extract_commands.extract()
+        #pass    
         #change_version.modify_version()        
     elif action == '':
         print("Invalid action specified")
