@@ -121,7 +121,8 @@ def upload_nexus_maven():
     #artname_lst = __main__.artifact_name.split("-", 10)
     artname_lst = longname.split("-", 10)
     
-    ver = re.search(r"\d\.\d\.\d[.\d]*[-]*[0-9A-z]*", longname)
+    #ver = re.search(r"\d*\.\d*\.\d*[.\d]*[-]*[0-9A-z]*", longname)
+    ver = re.search(r"\d*\.\d*\.\d*[.\d]*[-]*[+]*[0-9A-Za-z]*[.]*[0-9a-zA-Z]*[+]*[0-9a-zA-Z]*", longname)
     
     if ver:
         if __main__.debug == 1:
@@ -130,7 +131,7 @@ def upload_nexus_maven():
         print("No version number found in file name specified")
         return __main__.sys.exit(1)
     
-    actual_artifact_name = re.sub(r"\d\.\d\.\d[.\d]*[-]*[0-9A-z]*", '', longname)
+    actual_artifact_name = re.sub(r"\d*\.\d*\.\d*[.\d]*[-]*[+]*[0-9A-Za-z]*[.]*[0-9a-zA-Z]*[+]*[0-9a-zA-Z]*", '', longname)
     
     if actual_artifact_name.endswith("-"):
         actual_artifact_name = actual_artifact_name[:-1]
